package com.ruoyi.tcZz.mapper;

import java.util.List;
import com.ruoyi.tcZz.domain.TcCy;
import org.apache.ibatis.annotations.Param;

/**
 * 词云Mapper接口
 * 
 * @author ruoyi
 * @date 2023-10-13
 */
public interface TcCyMapper 
{
    /**
     * 查询词云
     * 
     * @param id 词云主键
     * @return 词云
     */
    public TcCy selectTcCyById(Long id);

    /**
     * 查询词云列表
     * 
     * @param tcCy 词云
     * @return 词云集合
     */
    public List<TcCy> selectTcCyList(TcCy tcCy);

    /**
     * 新增词云
     * 
     * @param tcCy 词云
     * @return 结果
     */
    public int insertTcCy(TcCy tcCy);

    /**
     * 修改词云
     * 
     * @param tcCy 词云
     * @return 结果
     */
    public int updateTcCy(TcCy tcCy);

    /**
     * 删除词云
     * 
     * @param id 词云主键
     * @return 结果
     */
    public int deleteTcCyById(Long id);

    /**
     * 批量删除词云
     * 
     * @param ids 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteTcCyByIds(Long[] ids);
    /**
     * 批量启用禁用
     *
     *
     */
    public void updateByisStatus(@Param("isStatus") Integer isStatus, @Param("ids") List<String> ids);
}
